
# This file was generated by 'versioneer.py' (0.10+) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

versions = {'full_revisionid': '084fd68534d30e3459b2f68d3b7116b9514046b7', 'describe': '0.3.3-dirty', 'dash_dirty': '-dirty', 'distance': 0, 'default': '0.3.3-dirty', 'closest_tag_or_zero': '0.3.3', 'pep440': '0.3.3.dev0', 'long': '0.3.3-0-g084fd68-dirty', 'closest_tag': '0.3.3', 'dirty': True, 'short_revisionid': '084fd68', 'dash_distance': ''}


def get_versions(default={}, verbose=False):
    return versions
def get_version():
    return version_string_template % versions
